@@ -11,7 +11,7 @@ has 'props'       => (is => 'ro', isa => 'Str', required => 1);
 has 'inner_texts' => (is => 'ro', required => 1,
                       isa => 'ArrayRef[MsOffice::Word::Surgeon::Text]');
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 sub as_xml {
   my $self = shift;
@@ -100,7 +100,7 @@ sub remove_caps_property {
   my $self = shift;
 
   if ($self->{props} =~ s[<w:caps/>][]) {
-    $_->uppercase foreach @{$self->inner_texts};
+    $_->to_uppercase foreach @{$self->inner_texts};
   }
 }
 
